@@ -19,7 +19,7 @@
 # FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS
 # IN THE SOFTWARE.
 
-
+import dataclasses
 import os
 import re
 import textwrap
@@ -38,7 +38,6 @@ from lib2to3.pgen2 import token
 from lib2to3.pgen2.parse import ParseError
 from lib2to3.pygram import python_symbols as syms
 from lib2to3.pytree import Leaf, Node
-from nr.databind.core import Field, Struct  # type: ignore
 
 _REVERSE_SYMS = {v: k for k, v in vars(syms).items() if isinstance(v, int)}
 _REVERSE_TOKEN = {v: k for k, v in vars(token).items() if isinstance(v, int)}
@@ -58,9 +57,10 @@ def find(predicate, iterable):
   return None
 
 
-class ParserOptions(Struct):
-  print_function = Field(bool, default=True)
-  treat_singleline_comment_blocks_as_docstrings = Field(bool, default=False)
+@dataclasses.dataclass
+class ParserOptions:
+  print_function: bool = True
+  treat_singleline_comment_blocks_as_docstrings: bool = False
 
 
 class Parser:
@@ -332,7 +332,7 @@ class Parser:
       metaclass, bases = self.parse_classdef_rawargs(node)
 
     suite = find(lambda x: x.type == syms.suite, node.children)
-    docstring = self.get_docstring_from_first_node(suite)
+    docstring = self.get_docstring_from_first_node(suite) if suite else None
     class_ = Class(
       name=name,
       location=self.location_from(node),
@@ -342,7 +342,7 @@ class Parser:
       decorations=decorations,
       members=[])
 
-    for child in suite.children:
+    for child in suite.children if suite else []:
       if isinstance(child, Node):
         member = self.parse_declaration(class_, child)
         if metaclass is None and isinstance(member, Data) and \
@@ -384,6 +384,7 @@ class Parser:
     node either declares a class or function.
     """
 
+    assert parent is not None
     node = find(lambda x: isinstance(x, Node), parent.children)
     if node and node.type == syms.simple_stmt and node.children[0].type == token.STRING:
       return self.prepare_docstring(node.children[0].value)
